from bluer_options import env
from bluer_options import string
from bluer_options.web.access.vars import dict_of_variables


def as_str(
    emoji: bool = True,
    timestamp: bool = False,
) -> str:
    return "{} {}{}".format(
        (
            "{} -".format(
                string.timestamp(
                    unique_length=0,
                )
            )
            if timestamp
            else "access:"
        ),
        ", ".join(
            [
                "{}{}".format(
                    name,
                    (
                        (" ✅" if emoji else "")
                        if info["value"]
                        else (" 🛑" if emoji else " X")
                    ),
                )
                for name, info in dict_of_variables(for_logging=True).items()
            ]
        ),
        " | ⛓️‍💥 [ forced offline]" if env.BLUER_AI_FORCE_OFFLINE else "",
    )



import argparse

from blueness import module
from blueness.argparse.generic import sys_exit

from bluer_options import NAME
from bluer_options.web.access.as_str import as_str
from bluer_options.web.access.check import check
from bluer_options.web.access.color import get_color
from bluer_options.web.access.vars import dict_of_variables
from bluer_options.logger import logger

NAME = module.name(__file__, NAME)

list_of_tasks = [
    "as_str",
    "check",
    "get_color",
    "get_var_name",
]

parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    help=" | ".join(list_of_tasks),
)
parser.add_argument(
    "--emoji",
    type=int,
    default=1,
    help="0|1",
)
parser.add_argument(
    "--keyword",
    type=str,
)
parser.add_argument(
    "--timeout",
    type=int,
    default=3,
    help="in seconds",
)
parser.add_argument(
    "--timestamp",
    type=int,
    default=0,
    help="0|1",
)
parser.add_argument(
    "--url",
    type=str,
)
parser.add_argument(
    "--verbose",
    type=int,
    default=0,
    help="0|1",
)
args = parser.parse_args()

success = args.task in list_of_tasks
if args.task == "as_str":
    logger.info(
        as_str(
            emoji=args.emoji == 1,
            timestamp=args.timestamp == 1,
        )
    )
elif args.task == "check":
    print(
        int(
            check(
                args.url,
                timeout=args.timeout,
                verbose=args.verbose == 1,
            )
        )
    )
elif args.task == "get_color":
    print(get_color())
elif args.task == "get_var_name":
    print(
        dict_of_variables()
        .get(args.keyword, {})
        .get(
            "name",
            "",
        )
    )
else:
    success = None

sys_exit(logger, NAME, args.task, success)



from typing import Any, Type

from bluer_options.logger import logger


def is_a_dict(
    things: Any,
    key_type: Type = str,
    value_type: Type = int,
    log: bool = False,
) -> bool:
    if not isinstance(things, dict):
        if log:
            logger.error(f"{things.__class__.__name__} is not a dict.")
        return False

    for key, value in things.items():
        if not isinstance(key, key_type):
            if log:
                logger.error(
                    "the key: {}, is a {}, not a {}.".format(
                        key,
                        key.__class__.__name__,
                        key_type,
                    )
                )
            return False

        if not isinstance(value, value_type):
            if log:
                logger.error(
                    "the value: {}, is a {}, not a {}.".format(
                        value,
                        value.__class__.__name__,
                        value_type,
                    )
                )
            return False

    return True



from typing import Dict

from bluer_options import env


def dict_of_variables(
    for_logging: bool = False,
) -> Dict[str, Dict]:
    output = {
        "cloud": {
            "name": "BLUER_AI_CLOUD_IS_ACCESSIBLE",
            "value": env.BLUER_AI_CLOUD_IS_ACCESSIBLE,
        },
        "web": {
            "name": "BLUER_AI_WEB_IS_ACCESSIBLE",
            "value": env.BLUER_AI_WEB_IS_ACCESSIBLE,
        },
        "pypi": {
            "name": "BLUER_AI_PYPI_IS_ACCESSIBLE",
            "value": env.BLUER_AI_PYPI_IS_ACCESSIBLE,
        },
    }

    if not for_logging:
        output["forced_offline"] = {
            "name": "BLUER_AI_FORCE_OFFLINE",
            "value": env.BLUER_AI_FORCE_OFFLINE,
        }

    return output



import numpy as np

from bluer_options.web.access.vars import dict_of_variables


def get_color() -> str:
    heat = "55"

    dict_of_variables_ = dict_of_variables()

    if not dict_of_variables_["pypi"]["value"]:
        # blue
        return f"0000{heat}"

    if not dict_of_variables_["web"]["value"]:
        # yellow
        return f"{heat}{heat}00"

    if not dict_of_variables_["cloud"]["value"]:
        # red
        return f"{heat}0000"

    return "000000"



import requests

from blueness import module

from bluer_options import NAME
from bluer_options import env
from bluer_options import string
from bluer_options.timing import ElapsedTimer
from bluer_options.logger import logger


NAME = module.name(__file__, NAME)


def check(
    url,
    timeout: int = 3,
    verbose: bool = False,
) -> bool:
    forced_offline: bool = env.BLUER_AI_FORCE_OFFLINE == 1

    if verbose:
        logger.info(
            "{}.check[timeout={}]({})?{}".format(
                NAME,
                string.pretty_duration(
                    timeout,
                    short=True,
                ),
                url,
                " [⛓️‍💥 forced offline]" if forced_offline else "",
            )
        )

    if forced_offline:
        return False

    success = False
    elapsed_timer = ElapsedTimer()
    try:
        response = requests.get(
            url,
            timeout=timeout,
        )
        success = response.status_code == 200
    except Exception as e:
        if verbose:
            logger.warning(e)

    if verbose:
        logger.info(
            "{} in {}.".format(
                "succeeded" if success else "failed",
                elapsed_timer.as_str(),
            )
        )

    return success



import argparse

from blueness import module
from blueness.argparse.generic import sys_exit

from bluer_options import NAME
from bluer_options.host.functions import get_name, tensor_processing_signature
from bluer_options.logger import logger

NAME = module.name(__file__, NAME)

list_of_tasks = [
    "get",
    "tensor_processing_signature",
]

parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    default="get",
    help=" | ".join(list_of_tasks),
)
parser.add_argument(
    "--keyword",
    type=str,
    help="name",
)
args = parser.parse_args()


success = args.task in list_of_tasks
# bash-tested in test_bluer_ai_host in bluer-objects.
if args.task == "get":
    success = True
    output = f"unknown-{args.keyword}"

    if args.keyword == "name":
        output = get_name()

    print(output)
elif args.task == "tensor_processing_signature":
    print(", ".join(tensor_processing_signature()))
else:
    success = None


sys_exit(logger, NAME, args.task, success, log=False)
